---
name: User Experience (UX) issue
about: Describe an issue with the User Experience of ilab
title: ''
labels: UX
assignees: ''

---

**What is the current experience of ilab you've found issue with?**
<!-- A clear and concise description of what the experience you'd using ilab is -->

**How do you think the described experience should be?**
<!-- A clear and concise description of how you think the experience you had should be -->

**What is the benefit of the change you are proposing?**
<!-- Justify your call to change the CLI here -->

**If applicable, how would backwards-compatability be handled?**
<!-- Feel free to remove this section if this does not apply -->

**Additional context**
<!-- Add any other context or screenshots about the design change here. -->
